Contact Information | Global Grey
Description: Contact Information page for Global Grey

Download free public domain ebooks: pdfs, epubs and ebooks for Kindle

Should you want to contact me for any reason, you can do so here.

If you are having a problem downloading a book, please state which one.

If you are requesting a book to be put up on the site, please remember it must be in the public domain.
If you are not sure, I am more than happy to check. If you know, however, that the book is quite new and very much in copyright, and you are after an illegal copy; I cannot help you.

Also...a friendly heads-up before you fire off that message beginning 'Dear Sir'...I'm a woman.

If your email is sent between 5am – 6.30pm GMT, you should usually get an answer within the hour. To see what time it currently is where I am, you can go here.

Name

E-Mail (Required)

Comment